[−][src]Struct serde_pointer::Pointer
Represents a pointer to the data as defined in the RFC6901 - the JSON Pointer specification.
Methods
impl Pointer[src]
pub fn push(&mut self, step: Step) -> &mut Self[src]
pub fn pop(&mut self) -> Option<Step>[src]
pub fn insert(&mut self, index: usize, step: Step)[src]
pub fn remove(&mut self, index: usize) -> Step[src]
pub fn traverse<'a>(&self, val: &'a Value) -> Option<ValuePointer<'a>>[src]
Traverses the provided value and finds the data this pointer points to in it, if any.
pub fn find<'a>(&self, val: &'a Value) -> Option<&'a Value>[src]
A simple override of traverse() that directly exposes the found value, if any.