Struct serde_pointer::Pointer
source · pub struct Pointer { /* private fields */ }Expand description
Represents a pointer to the data as defined in the RFC6901 - the JSON Pointer specification.
Implementations
sourceimpl Pointer
impl Pointer
pub fn push(&mut self, step: Step) -> &mut Self
pub fn pop(&mut self) -> Option<Step>
pub fn insert(&mut self, index: usize, step: Step)
pub fn remove(&mut self, index: usize) -> Step
sourcepub fn traverse<'a>(&self, val: &'a Value) -> Option<ValuePointer<'a>>
pub fn traverse<'a>(&self, val: &'a Value) -> Option<ValuePointer<'a>>
Traverses the provided value and finds the data this pointer points to in it, if any.